@@ -11,6 +11,7 @@ from kubernetes.client import V1Affinity
 from kubernetes.client import V1Container
 from kubernetes.client import V1ObjectMeta
 from kubernetes.client import V1Pod
+from kubernetes.client import V1PodSecurityContext
 from kubernetes.client import V1PodSpec
 from kubernetes.client import V1ResourceRequirements
 from kubernetes.client.exceptions import ApiException
@@ -192,6 +193,35 @@ class KubernetesPodExecutor(TaskExecutor):
             )
             return
 
+        if (
+            pod.status.phase in {"Succeeded", "Failed"}
+            and task_metadata.task_state is KubernetesTaskState.TASK_PENDING
+        ):
+            logger.debug(
+                f"Adding running event for {pod_name}, Kubernetes appears to have "
+                "compacted the Running phase event."
+            )
+            self.task_metadata = self.task_metadata.set(
+                pod_name,
+                task_metadata.set(
+                    node_name=pod.spec.node_name,
+                    task_state=KubernetesTaskState.TASK_RUNNING,
+                    task_state_history=task_metadata.task_state_history.append(
+                        (KubernetesTaskState.TASK_RUNNING, time.time()),
+                    )
+                )
+            )
+            self.event_queue.put(
+                task_event(
+                    task_id=pod_name,
+                    terminal=False,
+                    timestamp=time.time(),
+                    raw=raw_event,
+                    task_config=task_metadata.task_config,
+                    platform_type="running"
+                )
+            )
+
         if (
             pod.status.phase == "Succeeded"
             and task_metadata.task_state is not KubernetesTaskState.TASK_FINISHED
@@ -392,7 +422,8 @@ class KubernetesPodExecutor(TaskExecutor):
             pod = V1Pod(
                 metadata=V1ObjectMeta(
                     name=task_config.pod_name,
-                    namespace=self.namespace
+                    namespace=self.namespace,
+                    labels=dict(task_config.labels),
                 ),
                 spec=V1PodSpec(
                     restart_policy=task_config.restart_policy,
@@ -401,6 +432,15 @@ class KubernetesPodExecutor(TaskExecutor):
                     node_selector=dict(task_config.node_selectors),
                     affinity=V1Affinity(
                         node_affinity=get_node_affinity(task_config.node_affinities),
+                    ),
+                    # we're hardcoding this as Default as this is what we generally use
+                    # internally - until we have a usecase for something that needs one
+                    # of the other DNS policies, we can probably punt on plumbing all the
+                    # bits for making this configurable
+                    dns_policy="Default",
+                    share_process_namespace=True,
+                    security_context=V1PodSecurityContext(
+                        fs_group=task_config.fs_group,
                     )
                 ),
             )
